#!perl

use strict;
use warnings;


use SDL::Tutorial::Tetris;

SDL::Tutorial::Tetris->play(@ARGV);
